OpenQSA provides this Python package for QSA analysis of signals, including the JSON files exported from RTXI.

It is recommended to install Python 3.7 with pip3 on the computer.

It is also a good practice to work in isolation inside a python3 virtual environment.

The package can be installed using pip3:

        pip3 install qsa

Detailed instructions for installation and use are given on the official web site [openqsa.org](http://openqsa.org)